==> prestashop_edition_basic_version_8.2.0.zip: modules/ps_checkout/src/Order/Query/GetOrderForPaymentReversedQuery.php <==
<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace PrestaShop\Module\PrestashopCheckout\Order\Query;

use PrestaShop\Module\PrestashopCheckout\PayPal\Order\Exception\PayPalOrderException;
use PrestaShop\Module\PrestashopCheckout\PayPal\Order\ValueObject\PayPalOrderId;
use PrestaShop\Module\PrestashopCheckout\PayPal\Payment\Capture\Exception\PayPalCaptureException;
use PrestaShop\Module\PrestashopCheckout\PayPal\Payment\Capture\ValueObject\PayPalCaptureId;

class GetOrderForPaymentReversedQuery
{
    /**
     * @var PayPalOrderId
     */
    private $orderPayPalId;

    /**
     * @var PayPalCaptureId
     */
    private $capturePayPalId;

    /**
     * @param string $orderPayPalId
     * @param string $capturePayPalId
     *
     * @throws PayPalOrderException
     * @throws PayPalCaptureException
     */
    public function __construct($orderPayPalId, $capturePayPalId)
    {
        $this->orderPayPalId = new PayPalOrderId($orderPayPalId);
        $this->capturePayPalId = new PayPalCaptureId($capturePayPalId);
    }

    /**
     * @return PayPalOrderId
     */
    public function getOrderPayPalId()
    {
        return $this->orderPayPalId;
    }

    public function getCapturePayPalId()
    {
        return $this->capturePayPalId;
    }
}

==> prestashop_edition_basic_version_8.2.1.zip: modules/ps_checkout/src/Order/Query/GetOrderForPaymentReversedQuery.php <==
<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */

namespace PrestaShop\Module\PrestashopCheckout\Order\Query;

use PrestaShop\Module\PrestashopCheckout\PayPal\Order\Exception\PayPalOrderException;
use PrestaShop\Module\PrestashopCheckout\PayPal\Order\ValueObject\PayPalOrderId;

class GetOrderForPaymentReversedQuery
{
    /**
     * @var PayPalOrderId
     */
    private $orderPayPalId;

    /**
     * @param string $orderPayPalId
     *
     * @throws PayPalOrderException
     */
    public function __construct($orderPayPalId)
    {
        $this->orderPayPalId = new PayPalOrderId($orderPayPalId);
    }

    /**
     * @return PayPalOrderId
     */
    public function getOrderPayPalId()
    {
        return $this->orderPayPalId;
    }
}
